"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOrCreateConversation = exports.getConversation = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveComWixpressInboxV2ConversationsServiceUrl(opts) {
    const domainToMappings = {
        'www.wixapis.com': [
            {
                srcPath: '/inbox/v2/conversations',
                destPath: '/v2/conversations',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/inbox-platform-conversations',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/inbox_conversations';
/**
 * Retrieves a conversation by conversation ID.
 *
 * If you don't have the conversation ID, use `getOrCreateConversation()` to retrieve the conversation using the visitor, contact, or member ID.
 *
 */
function getConversation(payload) {
    function __getConversation({ host }) {
        const metadata = {
            entityFqdn: 'wix.crm.inbox.v2.conversation',
            method: 'GET',
            methodFqn: 'com.wixpress.inbox.v2.ConversationsService.GetConversation',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressInboxV2ConversationsServiceUrl({
                protoPath: '/v2/conversations/{conversationId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __getConversation;
}
exports.getConversation = getConversation;
/** Retrieves a conversation by the specified visitor, contact, or member ID. If the conversation does not exist for the provided visitor, contact, or member, the function creates a new conversation. */
function getOrCreateConversation(payload) {
    function __getOrCreateConversation({ host }) {
        const metadata = {
            entityFqdn: 'wix.crm.inbox.v2.conversation',
            method: 'POST',
            methodFqn: 'com.wixpress.inbox.v2.ConversationsService.GetOrCreateConversation',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressInboxV2ConversationsServiceUrl({
                protoPath: '/v2/conversations',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __getOrCreateConversation;
}
exports.getOrCreateConversation = getOrCreateConversation;
//# sourceMappingURL=crm-inbox-v2-conversation-conversations.http.js.map