"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOrCreateConversation = exports.getConversation = exports.WebhookIdentityType = exports.SortOrder = exports.ChannelType = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixCrmInboxV2Conversation = __importStar(require("./crm-inbox-v2-conversation-conversations.http.js"));
var ChannelType;
(function (ChannelType) {
    ChannelType["UNKNOWN_CHANNEL_TYPE"] = "UNKNOWN_CHANNEL_TYPE";
    ChannelType["CHAT"] = "CHAT";
    ChannelType["EMAIL"] = "EMAIL";
    ChannelType["SMS"] = "SMS";
    ChannelType["FACEBOOK"] = "FACEBOOK";
    ChannelType["INSTAGRAM"] = "INSTAGRAM";
    ChannelType["WHATSAPP"] = "WHATSAPP";
})(ChannelType || (exports.ChannelType = ChannelType = {}));
var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (exports.SortOrder = SortOrder = {}));
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
/**
 * Retrieves a conversation by conversation ID.
 *
 * If you don't have the conversation ID, use `getOrCreateConversation()` to retrieve the conversation using the visitor, contact, or member ID.
 *
 * @param conversationId - Conversation ID.
 * @public
 * @documentationMaturity preview
 * @requiredField conversationId
 * @permissionId INBOX.READ_CONVERSATIONS
 * @permissionScope Manage Inbox Messages
 * @permissionScopeId SCOPE.DC-INBOX.MANAGE-MSGS
 * @permissionScope Read Inbox Messages
 * @permissionScopeId SCOPE.DC-INBOX.READ-MSGS
 * @applicableIdentity APP
 * @returns Retrieved conversation.
 * @fqn com.wixpress.inbox.v2.ConversationsService.GetConversation
 */
async function getConversation(conversationId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        conversationId: conversationId,
    });
    const reqOpts = ambassadorWixCrmInboxV2Conversation.getConversation(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)?.conversation;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { conversationId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['conversationId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getConversation = getConversation;
/**
 * Retrieves a conversation by the specified visitor, contact, or member ID. If the conversation does not exist for the provided visitor, contact, or member, the function creates a new conversation.
 * @public
 * @documentationMaturity preview
 * @requiredField participantId
 * @param participantId - ID of the visitor, contact, or member chatting with the business.
 * @permissionId INBOX.CREATE_CONVERSATIONS
 * @permissionScope Manage Inbox Messages
 * @permissionScopeId SCOPE.DC-INBOX.MANAGE-MSGS
 * @applicableIdentity APP
 * @fqn com.wixpress.inbox.v2.ConversationsService.GetOrCreateConversation
 */
async function getOrCreateConversation(participantId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        participantId: participantId,
    });
    const reqOpts = ambassadorWixCrmInboxV2Conversation.getOrCreateConversation(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { participantId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['participantId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getOrCreateConversation = getOrCreateConversation;
//# sourceMappingURL=crm-inbox-v2-conversation-conversations.universal.js.map