import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { Conversation, ConversationConversationsMergedEnvelope, ConversationNonNullableFields, GetOrCreateConversationResponse, GetOrCreateConversationResponseNonNullableFields, ParticipantId } from './crm-inbox-v2-conversation-conversations.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function getConversation(httpClient: HttpClient): GetConversationSignature;
interface GetConversationSignature {
    /**
     * Retrieves a conversation by conversation ID.
     *
     * If you don't have the conversation ID, use `getOrCreateConversation()` to retrieve the conversation using the visitor, contact, or member ID.
     *
     * @param - Conversation ID.
     * @returns Retrieved conversation.
     */
    (conversationId: string): Promise<Conversation & ConversationNonNullableFields>;
}
export declare function getOrCreateConversation(httpClient: HttpClient): GetOrCreateConversationSignature;
interface GetOrCreateConversationSignature {
    /**
     * Retrieves a conversation by the specified visitor, contact, or member ID. If the conversation does not exist for the provided visitor, contact, or member, the function creates a new conversation.
     * @param - ID of the visitor, contact, or member chatting with the business.
     */
    (participantId: ParticipantId): Promise<GetOrCreateConversationResponse & GetOrCreateConversationResponseNonNullableFields>;
}
export declare const onConversationConversationsMerged: EventDefinition<ConversationConversationsMergedEnvelope, "wix.crm.inbox.v2.conversation_conversations_merged">;
export { ActionEvent, AddConversationChannelsRequest, AddConversationChannelsResponse, BaseEventMetadata, ChannelType, ChatroomsMerged, Conversation, ConversationChannel, ConversationConversationsMergedEnvelope, ConversationDisplayData, ConversationNonNullableFields, ConversationsMerged, CursorPaging, Cursors, DeleteConversationRequest, DeleteConversationResponse, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, GetConversationRequest, GetConversationResponse, GetConversationResponseNonNullableFields, GetOrCreateConversationRequest, GetOrCreateConversationResponse, GetOrCreateConversationResponseNonNullableFields, IdentificationData, IdentificationDataIdOneOf, ListConversationsRequest, ListConversationsResponse, MessageEnvelope, PagingMetadataV2, ParticipantId, ParticipantIdIdOneOf, ReadConversationRequest, ReadConversationResponse, RestoreInfo, SortOrder, Sorting, WebhookIdentityType, WebhooksIdentificationData, WebhooksIdentificationDataIdOneOf, } from './crm-inbox-v2-conversation-conversations.universal.js';
