export interface Conversation {
    /**
     * Conversation ID.
     * @readonly
     */
    id?: string;
    /**
     * ID of the visitor, contact, or member who is chatting with the business.
     * @readonly
     */
    participant?: IdentificationData;
    /**
     * List of communication channels where the visitor, contact, or member can receive messages.
     * @readonly
     */
    channels?: ChannelType[];
    /** Display name and avatar for the business. */
    businessDisplayData?: ConversationDisplayData;
    /** Display name and avatar for the visitor, contact, or member. */
    participantDisplayData?: ConversationDisplayData;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /** ID of an anonymous site visitor. */
    anonymousVisitorId?: string;
    /**
     * ID of a site
     * [member](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fmember-permissions/members).
     */
    memberId?: string;
    /**
     * ID of a site
     * [contact](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fcontacts).
     * @readonly
     */
    contactId?: string | null;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /** ID of an anonymous site visitor. */
    anonymousVisitorId?: string;
    /**
     * ID of a site
     * [member](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fmember-permissions/members).
     */
    memberId?: string;
}
export declare enum ChannelType {
    UNKNOWN_CHANNEL_TYPE = "UNKNOWN_CHANNEL_TYPE",
    CHAT = "CHAT",
    EMAIL = "EMAIL",
    SMS = "SMS",
    FACEBOOK = "FACEBOOK",
    INSTAGRAM = "INSTAGRAM",
    WHATSAPP = "WHATSAPP"
}
export interface ConversationDisplayData {
    /**
     * Display name.
     * @readonly
     */
    name?: string;
    /**
     * Avatar image URL.
     * @readonly
     */
    imageUrl?: string | null;
}
export interface ConversationsMerged {
    /** List of old conversation IDs. */
    oldConversationIds?: string[];
    /** New conversation ID. */
    targetConversationId?: string;
}
export interface GetConversationRequest {
    /** Conversation ID. */
    conversationId: string;
}
export interface GetConversationResponse {
    /** Retrieved conversation. */
    conversation?: Conversation;
}
export interface GetOrCreateConversationRequest {
    /**
     * ID of the visitor, contact, or member chatting with the business.
     *
     * Required for 3rd-party apps.
     */
    participantId?: ParticipantId;
}
export interface ParticipantId extends ParticipantIdIdOneOf {
    /**
     * ID of a site
     * [contact](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fcontacts).
     */
    contactId?: string;
    /** ID of an anonymous site visitor. */
    anonymousVisitorId?: string;
    /**
     * ID of a site
     * [member](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fmember-permissions/members).
     */
    memberId?: string;
}
/** @oneof */
export interface ParticipantIdIdOneOf {
    /**
     * ID of a site
     * [contact](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fcontacts).
     */
    contactId?: string;
    /** ID of an anonymous site visitor. */
    anonymousVisitorId?: string;
    /**
     * ID of a site
     * [member](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fmember-permissions/members).
     */
    memberId?: string;
}
export interface GetOrCreateConversationResponse {
    /** Created or retrieved conversation. */
    conversation?: Conversation;
    /**
     * Indicates whether the conversation previously exists or was just created.
     *
     * If `true`, the conversation was just created.
     * If `false`, the conversation already existed.
     */
    newConversation?: boolean;
}
export interface ListConversationsRequest {
    paging?: CursorPaging;
    /** only message time is supported for field name */
    sorting?: Sorting;
}
export interface CursorPaging {
    /** Maximum number of items to return in the results. */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     */
    cursor?: string | null;
}
export interface Sorting {
    /** Name of the field to sort by. */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrder;
}
export declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
export interface ListConversationsResponse {
    conversations?: Conversation[];
    pagingMetadata?: PagingMetadataV2;
}
export interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
export interface Cursors {
    /** Cursor string pointing to the next page in the list of results. */
    next?: string | null;
    /** Cursor pointing to the previous page in the list of results. */
    prev?: string | null;
}
export interface DeleteConversationRequest {
    conversationId?: string;
}
export interface DeleteConversationResponse {
}
export interface AddConversationChannelsRequest {
    conversationId?: string;
    conversationChannels?: ConversationChannel[];
}
export interface ConversationChannel {
    channel?: ChannelType;
    /** TODO rename? - Shalom */
    recipients?: string[];
}
export interface AddConversationChannelsResponse {
}
export interface ChatroomsMerged {
    /** old chatroom ids */
    oldChatroomIds?: string[];
    /** new chatroom id */
    targetChatroomId?: string;
}
export interface Empty {
}
export interface ReadConversationRequest {
    conversationId?: string;
    channelId?: string | null;
    readBy?: ParticipantId;
    timestamp?: Date | null;
}
export interface ReadConversationResponse {
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entityAsJson?: string;
    /** Indicates the event was triggered by a restore-from-trashbin operation for a previously deleted entity */
    restoreInfo?: RestoreInfo;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntityAsJson?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted */
    deletedEntityAsJson?: string | null;
}
export interface ActionEvent {
    bodyAsJson?: string;
}
export interface MessageEnvelope {
    /** App instance ID. */
    instanceId?: string | null;
    /** Event type. */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: WebhooksIdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface WebhooksIdentificationData extends WebhooksIdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface WebhooksIdentificationDataIdOneOf {
    /** ID of a site visitor that has not logged in to the site. */
    anonymousVisitorId?: string;
    /** ID of a site visitor that has logged in to the site. */
    memberId?: string;
    /** ID of a Wix user (site owner, contributor, etc.). */
    wixUserId?: string;
    /** ID of an app. */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
interface IdentificationDataNonNullableFields {
    anonymousVisitorId: string;
    memberId: string;
}
interface ConversationDisplayDataNonNullableFields {
    name: string;
}
interface ConversationNonNullableFields {
    id: string;
    participant?: IdentificationDataNonNullableFields;
    channels: ChannelType[];
    businessDisplayData?: ConversationDisplayDataNonNullableFields;
    participantDisplayData?: ConversationDisplayDataNonNullableFields;
}
export interface GetConversationResponseNonNullableFields {
    conversation?: ConversationNonNullableFields;
}
export interface GetOrCreateConversationResponseNonNullableFields {
    conversation?: ConversationNonNullableFields;
    newConversation: boolean;
}
export {};
