import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixCrmInboxV2Conversation from './crm-inbox-v2-conversation-conversations.http.js';
export var ChannelType;
(function (ChannelType) {
    ChannelType["UNKNOWN_CHANNEL_TYPE"] = "UNKNOWN_CHANNEL_TYPE";
    ChannelType["CHAT"] = "CHAT";
    ChannelType["EMAIL"] = "EMAIL";
    ChannelType["SMS"] = "SMS";
    ChannelType["FACEBOOK"] = "FACEBOOK";
    ChannelType["INSTAGRAM"] = "INSTAGRAM";
    ChannelType["WHATSAPP"] = "WHATSAPP";
})(ChannelType || (ChannelType = {}));
export var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (SortOrder = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Retrieves a conversation by conversation ID.
 *
 * If you don't have the conversation ID, use `getOrCreateConversation()` to retrieve the conversation using the visitor, contact, or member ID.
 *
 * @param conversationId - Conversation ID.
 * @public
 * @documentationMaturity preview
 * @requiredField conversationId
 * @permissionId INBOX.READ_CONVERSATIONS
 * @permissionScope Manage Inbox Messages
 * @permissionScopeId SCOPE.DC-INBOX.MANAGE-MSGS
 * @permissionScope Read Inbox Messages
 * @permissionScopeId SCOPE.DC-INBOX.READ-MSGS
 * @applicableIdentity APP
 * @returns Retrieved conversation.
 * @fqn com.wixpress.inbox.v2.ConversationsService.GetConversation
 */
export async function getConversation(conversationId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        conversationId: conversationId,
    });
    const reqOpts = ambassadorWixCrmInboxV2Conversation.getConversation(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)?.conversation;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { conversationId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['conversationId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves a conversation by the specified visitor, contact, or member ID. If the conversation does not exist for the provided visitor, contact, or member, the function creates a new conversation.
 * @public
 * @documentationMaturity preview
 * @requiredField participantId
 * @param participantId - ID of the visitor, contact, or member chatting with the business.
 * @permissionId INBOX.CREATE_CONVERSATIONS
 * @permissionScope Manage Inbox Messages
 * @permissionScopeId SCOPE.DC-INBOX.MANAGE-MSGS
 * @applicableIdentity APP
 * @fqn com.wixpress.inbox.v2.ConversationsService.GetOrCreateConversation
 */
export async function getOrCreateConversation(participantId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        participantId: participantId,
    });
    const reqOpts = ambassadorWixCrmInboxV2Conversation.getOrCreateConversation(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { participantId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['participantId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=crm-inbox-v2-conversation-conversations.universal.js.map